/* SPDX-License-Identifier: Zlib */

#ifndef ZATHURA_VERSION_H
#define ZATHURA_VERSION_H

#define ZATHURA_VERSION_MAJOR 2026
#define ZATHURA_VERSION_MINOR 07
#define ZATHURA_VERSION_REV 18
#define ZATHURA_VERSION "2026.07.18"
#define ZATHURA_API_VERSION 8
#define ZATHURA_ABI_VERSION 9

#endif
